﻿using DotNetCore.CAP;
using Hotline.Share.Dtos.Knowledge;
using Hotline.Share.Dtos.Order;
using Hotline.Share.Enums.Order;
using MapsterMapper;
using MediatR;
using Microsoft.AspNetCore.Mvc;
using Sharing.Application;
using Sharing.Notifications.HuiJu;
using Sharing.Notifications.Knowledge;
using Sharing.Notifications.XieTong;
using Sharing.Province.Dtos.Extend;
using Sharing.Province.Dtos.HuiJu.Send;
using Sharing.Province.Dtos.XieTong.Send;
using Sharing.Province.Extend;
using Sharing.Province.HuiJu.Send;
using Sharing.Province.Other;
using Sharing.Province.XieTong.Knowledge;
using Sharing.Province.XieTong.Receive;
using Sharing.Province.XieTong.Send;

namespace Sharing.Api.Controllers
{
    /// <summary>
    /// 
    /// </summary>
    public class HotlineMessageReceiveController : Controller
    {
        #region 注入
        private readonly IMediator _mediator;
        private readonly ILogger<HotlineMsgReceiver> _logger;
        private readonly IMapper _mapper;
        private readonly IGetCaseResultReceiveRepository _getCaseResultReceiveRepository;
        private readonly IGetCaseProcessReceiveRepository _getCaseProcessReceiveRepository;
        private readonly IGetVisitInfoReceiveRepository _getVisitInfoReceiveRepository;
        private readonly IGetCaseBackApplyRepository _getCaseBackApplyRepository;
        private readonly IDelayCaseInfoSendRepository _delayCaseInfoSendRepository;
        private readonly ISendSuperviseProcessInfoRepository _sendSuperviseProcessInfoRepository;
        private readonly ISendSuperviseResultInfoRepository _sendSuperviseResultInfoRepository;
        private readonly ISubmitCaseInfoRepository _submitCaseInfoRepository;
        private readonly ISubmitCaseResultRepository _submitCaseResultRepository;
        private readonly ISubmitCaseProcessRepository _submitCaseProcessRepository;
        private readonly ISubmitVisitInfoRepository _submitVisitInfoRepository;
        private readonly ISubmitCaseRecordRepository _submitCaseRecordRepository;
        private readonly ISubmitCaseTotalRepository _submitCaseTotalRepository;
        private readonly ISendCaseInfoRepository _sendCaseInfoRepository;
        private readonly ISupplyCaseInfoSendRepository _supplyCaseInfoSendRepository;
        private readonly IRevokeCaseInfoRepository _revokeCaseInfoRepository;
        private readonly IRemindCaseInfoRepository _remindCaseInfoRepository;
        private readonly IGetKnowledgeInfoSendRepository _getKnowledgeInfoSendRepository;
        private readonly IGetKnowledgeInfoUpdateRepository _getKnowledgeInfoUpdateRepository;
        private readonly IGetKnowledgeInfoAbandonRepository _getKnowledgeInfoAbandonRepository;
        private readonly ISendRealTimeStatusRepository _sendRealTimeStatusRepository;
        private readonly IScreenCaseInfoSendRepository _screenCaseInfoSendRepository;
        private readonly IZMHDCaseInfoPublicRepository _zMHDCaseInfoPublicRepository;
        private readonly IProvinceService _provinceService;
        private readonly IConfiguration _config;
        private readonly string AreaCode = "";
        private readonly IKnowledgeRawDataRepository _knowledgeRawDataRepository;
        private readonly IWaitingPushDataRepository _waitingPushDataRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="mediator"></param>
        /// <param name="logger"></param>
        /// <param name="mapper"></param>
        /// <param name="getCaseResultReceiveRepository"></param>
        /// <param name="getCaseProcessReceiveRepository"></param>
        /// <param name="getVisitInfoReceiveRepository"></param>
        /// <param name="getCaseBackApplyRepository"></param>
        /// <param name="delayCaseInfoSendRepository"></param>
        /// <param name="sendSuperviseProcessInfoRepository"></param>
        /// <param name="sendSuperviseResultInfoRepository"></param>
        /// <param name="submitCaseInfoRepository"></param>
        /// <param name="submitCaseResultRepository"></param>
        /// <param name="submitCaseProcessRepository"></param>
        /// <param name="submitVisitInfoRepository"></param>
        /// <param name="submitCaseRecordRepository"></param>
        /// <param name="submitCaseTotalRepository"></param>
        /// <param name="sendCaseInfoRepository"></param>
        /// <param name="supplyCaseInfoSendRepository"></param>
        /// <param name="revokeCaseInfoRepository"></param>
        /// <param name="remindCaseInfoRepository"></param>
        /// <param name="getKnowledgeInfoSendRepository"></param>
        /// <param name="getKnowledgeInfoUpdateRepository"></param>
        /// <param name="getKnowledgeInfoAbandonRepository"></param>
        /// <param name="sendRealTimeStatusRepository"></param>
        /// <param name="screenCaseInfoSendRepository"></param>
        /// <param name="zMHDCaseInfoPublicRepository"></param>
        /// <param name="provinceService"></param>
        /// <param name="config"></param>
        /// <param name="knowledgeRawDataRepository"></param>
        /// <param name="waitingPushDataRepository"></param>
        public HotlineMessageReceiveController(IMediator mediator, ILogger<HotlineMsgReceiver> logger, IMapper mapper
            , IGetCaseResultReceiveRepository getCaseResultReceiveRepository, IGetCaseProcessReceiveRepository getCaseProcessReceiveRepository
            , IGetVisitInfoReceiveRepository getVisitInfoReceiveRepository, IGetCaseBackApplyRepository getCaseBackApplyRepository
            , IDelayCaseInfoSendRepository delayCaseInfoSendRepository, ISendSuperviseProcessInfoRepository sendSuperviseProcessInfoRepository
            , ISendSuperviseResultInfoRepository sendSuperviseResultInfoRepository, ISubmitCaseInfoRepository submitCaseInfoRepository
            , ISubmitCaseResultRepository submitCaseResultRepository, ISubmitCaseProcessRepository submitCaseProcessRepository
            , ISubmitVisitInfoRepository submitVisitInfoRepository, ISubmitCaseRecordRepository submitCaseRecordRepository
            , ISubmitCaseTotalRepository submitCaseTotalRepository, ISendCaseInfoRepository sendCaseInfoRepository
            , ISupplyCaseInfoSendRepository supplyCaseInfoSendRepository, IRevokeCaseInfoRepository revokeCaseInfoRepository
            , IRemindCaseInfoRepository remindCaseInfoRepository, IGetKnowledgeInfoSendRepository getKnowledgeInfoSendRepository
            , IGetKnowledgeInfoUpdateRepository getKnowledgeInfoUpdateRepository, IGetKnowledgeInfoAbandonRepository getKnowledgeInfoAbandonRepository
            , ISendRealTimeStatusRepository sendRealTimeStatusRepository, IScreenCaseInfoSendRepository screenCaseInfoSendRepository
            , IZMHDCaseInfoPublicRepository zMHDCaseInfoPublicRepository, IProvinceService provinceService, IConfiguration config
            , IKnowledgeRawDataRepository knowledgeRawDataRepository, IWaitingPushDataRepository waitingPushDataRepository)
        {
            _mediator = mediator;
            _logger = logger;
            _mapper = mapper;
            _getCaseResultReceiveRepository = getCaseResultReceiveRepository;
            _getCaseProcessReceiveRepository = getCaseProcessReceiveRepository;
            _getVisitInfoReceiveRepository = getVisitInfoReceiveRepository;
            _getCaseBackApplyRepository = getCaseBackApplyRepository;
            _delayCaseInfoSendRepository = delayCaseInfoSendRepository;
            _sendSuperviseProcessInfoRepository = sendSuperviseProcessInfoRepository;
            _sendSuperviseResultInfoRepository = sendSuperviseResultInfoRepository;
            _submitCaseInfoRepository = submitCaseInfoRepository;
            _submitCaseResultRepository = submitCaseResultRepository;
            _submitCaseProcessRepository = submitCaseProcessRepository;
            _submitVisitInfoRepository = submitVisitInfoRepository;
            _submitCaseRecordRepository = submitCaseRecordRepository;
            _submitCaseTotalRepository = submitCaseTotalRepository;
            _sendCaseInfoRepository = sendCaseInfoRepository;
            _supplyCaseInfoSendRepository = supplyCaseInfoSendRepository;
            _revokeCaseInfoRepository = revokeCaseInfoRepository;
            _remindCaseInfoRepository = remindCaseInfoRepository;
            _getKnowledgeInfoSendRepository = getKnowledgeInfoSendRepository;
            _getKnowledgeInfoUpdateRepository = getKnowledgeInfoUpdateRepository;
            _getKnowledgeInfoAbandonRepository = getKnowledgeInfoAbandonRepository;
            _sendRealTimeStatusRepository = sendRealTimeStatusRepository;
            _screenCaseInfoSendRepository = screenCaseInfoSendRepository;
            _zMHDCaseInfoPublicRepository = zMHDCaseInfoPublicRepository;

            _provinceService = provinceService;
            _config = config;
            AreaCode = _config.GetSection("AreaCode").Get<string>();//获取区域配置信息
            _knowledgeRawDataRepository = knowledgeRawDataRepository;
            _waitingPushDataRepository = waitingPushDataRepository;
        }
        #endregion

        #region 协同-第一批次
        /// <summary>
        /// 服务工单交办处理结果  ---已在汇聚众完成
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        //[CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderGetCaseResultReceive)]
        public async Task GetCaseResultReceive(GetCaseResultReceiveInfo dto)
        {
            var data = _mapper.Map<GetCaseResultReceive>(dto);
            data.AreaCode = AreaCode;
            //将上报信息写入本地库
            var id = await _getCaseResultReceiveRepository.AddAsync(data);

            data.Id = id;
            //信息上报
            await _mediator.Publish(new GetCaseResultReceiveNotification(data));
        }

        /// <summary>
        /// 服务工单交办处理过程  ---已在汇聚众完成
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        //[CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderGetCaseProcessReceive)]
        public async Task GetCaseProcessReceive(GetCaseProcessReceiveInfo dto)
        {
            var data = _mapper.Map<GetCaseProcessReceive>(dto);
            data.AreaCode = AreaCode;
            //将上报信息写入本地库
            var id = await _getCaseProcessReceiveRepository.AddAsync(data);

            data.Id = id;
            //信息上报
            await _mediator.Publish(new GetCaseProcessReceiveNotification(data));
        }

        /// <summary>
        /// 服务工单交办评价    ---已在汇聚众完成
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        //[CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderGetVisitInfoReceive)]
        public async Task GetVisitInfoReceive(GetVisitInfoReceiveInfo dto)
        {
            var data = _mapper.Map<GetVisitInfoReceive>(dto);
            data.AreaCode = AreaCode;
            //将上报信息写入本地库
            var id = await _getVisitInfoReceiveRepository.AddAsync(data);

            data.Id = id;
            //信息上报
            await _mediator.Publish(new GetVisitInfoReceiveNotification(data));
        }

        /// <summary>
        /// 退回申请  
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        //[CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderGetCaseBackApply)]
        public async Task GetCaseBackApply(GetCaseBackApplyInfo dto)
        {
            var data = _mapper.Map<GetCaseBackApply>(dto);
            data.AreaCode = AreaCode;
            //将上报信息写入本地库
            var id = await _getCaseBackApplyRepository.AddAsync(data);

            data.Id = id;
            //信息上报
            await _mediator.Publish(new GetCaseBackApplyNotification(data));
        }

        /// <summary>
        /// 服务工单申请延时  
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        //[CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderDelayCaseInfoSend)]
        public async Task DelayCaseInfoSend(DelayCaseInfoSendInfo dto)
        {
            var data = _mapper.Map<DelayCaseInfoSend>(dto);
            data.AreaCode = AreaCode;
            //将上报信息写入本地库
            var id = await _delayCaseInfoSendRepository.AddAsync(data);

            data.Id = id;
            //信息上报
            await _mediator.Publish(new DelayCaseInfoSendNotification(data));
        }

        /// <summary>
        /// 服务工单督办过程  
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        //[CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderSendSuperviseProcessInfo)]
        public async Task SendSuperviseProcessInfo(SendSuperviseProcessInfoInfo dto)
        {
            var data = _mapper.Map<SendSuperviseProcessInfo>(dto);
            data.AreaCode = AreaCode;
            //将上报信息写入本地库
            var id = await _sendSuperviseProcessInfoRepository.AddAsync(data);

            data.Id = id;
            //信息上报
            await _mediator.Publish(new SendSuperviseProcessInfoNotification(data));
        }

        /// <summary>
        /// 服务工单督办结果  
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        //[CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderSendSuperviseResultInfo)]
        public async Task SendSuperviseResultInfo(SendSuperviseResultInfoInfo dto)
        {
            var data = _mapper.Map<SendSuperviseResultInfo>(dto);
            data.AreaCode = AreaCode;
            //将上报信息写入本地库
            var id = await _sendSuperviseResultInfoRepository.AddAsync(data);

            data.Id = id;
            //信息上报
            await _mediator.Publish(new SendSuperviseResultInfoNotification(data));
        }

        /// <summary>
        /// 工单发起甄别  
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        //[CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderScreenCaseInfoSend)]
        public async Task ScreenCaseInfoSend(ScreenCaseInfoSendInfo dto)
        {
            var data = _mapper.Map<ScreenCaseInfoSend>(dto);
            data.AreaCode = AreaCode;
            //将上报信息写入本地库
            var id = await _screenCaseInfoSendRepository.AddAsync(data);

            data.Id = id;
            //信息上报
            await _mediator.Publish(new ScreenCaseInfoSendNotification(data));
        }

        /// <summary>
        /// 政民互动提交公开  
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        //[CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderZMHDCaseInfoPublic)]
        public async Task ZMHDCaseInfoPublic(ZMHDCaseInfoPublicInfo dto)
        {
            var data = _mapper.Map<ZMHDCaseInfoPublic>(dto);
            data.AreaCode = AreaCode;
            //将上报信息写入本地库
            var id = await _zMHDCaseInfoPublicRepository.AddAsync(data);

            data.Id = id;
            //信息上报
            await _mediator.Publish(new ZMHDCaseInfoPublicNotification(data));
        }
        #endregion

        #region 汇聚-第二批次

        #region 已对接
        /// <summary>
        /// 热线工单流程开启 --服务工单受理
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderFlowStarted)]
        public async Task OrderFlowStarted(OrderDto dto)
        {
            //如果不是省上派下来的工单，需要汇聚到省上
            if (dto.Source != ESource.ProvinceStraight)
            {
                var submitCaseInfo = await _provinceService.InitData(dto);
                await _mediator.Publish(new OrderCreatedNotification(submitCaseInfo));

                //如果是12315市场监管局受理单 推送扩展信息
                if (dto.OrderType == EOrderType.MarketSupervisionBy12315)
                {
                    //推送工单扩展信息
                    await _provinceService.SubmitCaseExtends(dto);
                }
            }
        }

        /// <summary>
        /// 热线工单期满时间变更--服务工单受理
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderExpiredTimeUpdate)]
        public async Task OrderExpiredTimeUpdate(OrderDto dto)
        {
            //如果不是省上派下来的工单，需要汇聚到省上
            if (dto.Source != ESource.ProvinceStraight)
            {
                var submitCaseInfo = await _provinceService.InitData(dto);
                await _mediator.Publish(new OrderCreatedNotification(submitCaseInfo));
            }
        }

        /// <summary>
        /// 热线工单一级部门办理完---服务工单处理
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderLevelOneOrgHandled)]
        public async Task SubmitCaseProcess(OrderFlowDto dto)
        {
            //如果不是省上派下来的工单
            if (dto.Order.Source != ESource.ProvinceStraight)
                await _provinceService.SubmitCaseProcess(dto);//本地工单走市州接口
            else
            {
                //省上下来的工单走协同的接口
                var data = _mapper.Map<GetCaseProcessReceive>(dto);
                data.TacheName = "70:" + data.DeptName;
                //将上报信息写入本地库
                data.Id = await _getCaseProcessReceiveRepository.AddAsync(data);
                //信息上报
                await _mediator.Publish(new GetCaseProcessReceiveNotification(data));
            }
        }

        /// <summary>
        /// 回访完成---服务工单回访评价
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderVisited)]
        public async Task SubmitVisitInfo(PublishVisitDto dto)
        {
            //如果不是省上派下来的工单
            if (dto.Order.Source != ESource.ProvinceStraight)
                await _provinceService.SubmitVisitInfo(dto);
            else
            {
                var data = _mapper.Map<GetVisitInfoReceive>(dto);
                //将上报信息写入本地库
                data.Id = await _getVisitInfoReceiveRepository.AddAsync(data);
                //信息上报
                await _mediator.Publish(new GetVisitInfoReceiveNotification(data));
            }
        }

        /// <summary>
        /// 甄别通过---服务工单回访评价
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderScreenSuccess)]
        public async Task SubmitOrderScreenSuccess(PublishVisitDto dto)
        {
            //如果不是省上派下来的工单
            if (dto.Order.Source != ESource.ProvinceStraight)
                await _provinceService.SubmitVisitInfo(dto);
            else
            {
                var data = _mapper.Map<GetVisitInfoReceive>(dto);
                //将上报信息写入本地库
                data.Id = await _getVisitInfoReceiveRepository.AddAsync(data);
                //信息上报
                await _mediator.Publish(new GetVisitInfoReceiveNotification(data));
            }
        }

        #endregion









        /// <summary>
        ///热线工单归档---服务工单结果
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderFiled)]
        public async Task OrderFiled(OrderFlowDto dto)
        {
            //IsProvince 如果是false 则推送服务工单受理
            if (dto != null && dto.Order != null && !dto.Order.IsProvince)
            {
                //推送工单信息
                var submitCaseInfo = await _provinceService.InitData(dto.Order);
                await _mediator.Publish(new OrderCreatedNotification(submitCaseInfo));

            }
            //推送服务工单处理信息
            await _provinceService.SubmitCaseProcess(dto);

            //推送服务工单结果信息-组装110数据
            await _provinceService.SubmitCaseResult(dto);

        }








        /// <summary>
        /// 挂电话推送----电话记录
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        //[CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderSubmitCaseRecord)]
        public async Task SubmitCaseRecord(CaseRecord dto)
        {
            var data = _mapper.Map<SubmitCaseRecord>(dto);
            data.AreaCode = AreaCode;
            //将上报信息写入本地库
            var id = await _submitCaseRecordRepository.AddAsync(data);

            data.Id = id;
            //信息上报
            await _mediator.Publish(new SubmitCaseRecordNotification(data));
        }

        /// <summary>
        /// 关联工单了推送----电话记录
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        //[CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderSubmitCaseRecord)]
        public async Task SubmitCaseRecordOrder(CaseRecord dto)
        {
            var data = _mapper.Map<SubmitCaseRecord>(dto);
            data.AreaCode = AreaCode;
            //将上报信息写入本地库
            var id = await _submitCaseRecordRepository.AddAsync(data);

            data.Id = id;
            //信息上报
            await _mediator.Publish(new SubmitCaseRecordNotification(data));
        }

        /// <summary>
        /// 统计数据
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        //[CapSubscribe(Hotline.Share.Mq.EventNames.HotlineOrderSubmitCaseTotal)]
        public async Task SubmitCaseTotal(CaseTotal dto)
        {
            var data = _mapper.Map<SubmitCaseTotal>(dto);
            //将上报信息写入本地库
            var id = await _submitCaseTotalRepository.AddAsync(data);

            data.Id = id;
            //信息上报
            await _mediator.Publish(new SubmitCaseTotalNotification(data));
        }

       
        #endregion

        #region 协同-第三批次
        /// <summary>
        /// 服务工单上报  --- 部分字段未赋值处理
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        //[CapSubscribe(Hotline.Share.Mq.EventNames.SendCaseInfo)]
        public async Task SendCaseInfo(OrderDto dto)
        {
            //处理数据
            SendCaseInfo sendCaseInfo = new SendCaseInfo
            {
                OrderID = dto.Id,
                No = dto.No,
                CaseTitle = dto.Title,
                CaseRegister = dto.AcceptorName,
                CaseRegisterNo = dto.AcceptorStaffNo,
                CaseDate = Convert.ToDateTime(dto.CreationTime),
                PhoneNumber = dto.Contact,
                AppLicantName = dto.FromName,
                AppLicantAge = dto.AgeRangeCode,
                AppLicantId = dto.LicenceNo,
                CaseAccord = "",
                CaseContent = dto.Content,
                CaseProcessType = "",
                CaseIsPublic = "",
                CaseIsSecrect = "",
                CaseIsVisit = "",
                CaseLngLat = "",
                CaseEmotion = "",
                CaseAddress = "",
                EventDate = null,
                ThemeSerial = "",
                IsExtends = "",
                AreaCode = AreaCode,
                CaseSource = dto.SourceChannel
            };

            ////处理诉求渠道
            //switch (dto.Channel)
            //{
            //    case EChannel.Phone:
            //        sendCaseInfo.CaseSource = "RGDH";
            //        break;
            //    case EChannel.WxOfficial:
            //        sendCaseInfo.CaseSource = "WX";
            //        break;
            //    case EChannel.Web:
            //        sendCaseInfo.CaseSource = "WZ";
            //        break;
            //    case EChannel.App:
            //        sendCaseInfo.CaseSource = "Ap";
            //        break;
            //    case EChannel.WxMiniProgram:
            //        sendCaseInfo.CaseSource = "XCX";
            //        break;
            //}

            //处理性别
            switch (dto.FromGender)
            {
                case EGender.Female:
                    sendCaseInfo.AppLicantSex = "0";
                    break;
                case EGender.Male:
                    sendCaseInfo.AppLicantSex = "1";
                    break;
                case EGender.Unknown:
                    sendCaseInfo.AppLicantSex = "2";
                    break;
            }

            //处理证件类型
            sendCaseInfo.CertifiCateType = dto.LicenceTypeCode switch
            {
                "10" => "10",
                "40" => "20",
                "55" => "30",
                "57" => "40",
                _ => "50",
            };

            //处理受理类型
            switch (dto.AcceptType)
            {
                case EAcceptType.Consult:
                    sendCaseInfo.CaseType = "10";
                    break;
                case EAcceptType.Suggest:
                    sendCaseInfo.CaseType = "15";
                    break;
                case EAcceptType.SeekHelp:
                    sendCaseInfo.CaseType = "20";
                    break;
                case EAcceptType.Praise:
                    sendCaseInfo.CaseType = "25";
                    break;
                case EAcceptType.Report:
                    sendCaseInfo.CaseType = "30";
                    break;
                case EAcceptType.Complain:
                    sendCaseInfo.CaseType = "35";
                    break;
                case EAcceptType.Other:
                    sendCaseInfo.CaseType = "40";
                    break;
            }

            //处理紧急程度
            sendCaseInfo.CaseIsUrgent = dto.EmergencyLevel switch
            {
                EEmergencyLevel.QuiteEmergency => "10",
                EEmergencyLevel.Emergency => "20",
                _ => "30",
            };
            sendCaseInfo.Id = await _sendCaseInfoRepository.AddAsync(sendCaseInfo, HttpContext.RequestAborted);

            await _mediator.Publish(new SendCaseInfoNotification(sendCaseInfo));
        }

        /// <summary>
        /// 上报补充诉求
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        //[CapSubscribe(Hotline.Share.Mq.EventNames.SupplyCaseInfoSend)]
        public async Task SupplyCaseInfoSend(SupplyCaseInfoSendInfo dto)
        {
            var data = _mapper.Map<SupplyCaseInfoSend>(dto);
            data.AreaCode = AreaCode;
            //将上报信息写入本地库
            var id = await _supplyCaseInfoSendRepository.AddAsync(data);

            data.Id = id;
            //信息上报
            await _mediator.Publish(new SupplyCaseInfoSendNotification(data));
        }

        /// <summary>
        /// 服务工单撤单
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        //[CapSubscribe(Hotline.Share.Mq.EventNames.SendRevokeCaseInfo)]
        public async Task SendRevokeCaseInfo(RevokeCaseInfoInfo dto)
        {
            var data = _mapper.Map<RevokeCaseInfo>(dto);
            data.Direction = "1";
            data.AreaCode = AreaCode;
            //将上报信息写入本地库
            var id = await _revokeCaseInfoRepository.AddAsync(data);

            data.Id = id;
            //信息上报
            await _mediator.Publish(new SendRevokeCaseInfoNotification(data));
        }

        /// <summary>
        /// 服务工单催单
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        //[CapSubscribe(Hotline.Share.Mq.EventNames.SendRemindCaseInfo)]
        public async Task SendRemindCaseInfo(RemindCaseInfoInfo dto)
        {
            var data = _mapper.Map<RemindCaseInfo>(dto);
            data.Direction = "1";
            data.AreaCode = AreaCode;
            //将上报信息写入本地库
            var id = await _remindCaseInfoRepository.AddAsync(data);

            data.Id = id;
            //信息上报
            await _mediator.Publish(new SendRemindCaseInfoNotification(data));
        }

        #endregion

        #region 协同-第四批次

        #region 知识库
        /// <summary>
        /// 知识库上报
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineKnowledgeAdd)]
        public async Task GetKnowledgeInfoSend(KnowledgeSendDto dto)
        {
            var data = _mapper.Map<GetKnowledgeInfoSend>(dto);
            data.AreaCode = AreaCode;
            if (data.DisableDate == null)//如果没得有失效时间，默认在生效日期上面加10年
                data.DisableDate = data.BeginDate.Value.AddYears(10);
            //将上报信息写入本地库
            data.Id = await _getKnowledgeInfoSendRepository.AddAsync(data);

            //保存原始数据
            var dataRaw = _mapper.Map<KnowledgeRawData>(data);
            await _knowledgeRawDataRepository.AddAsync(dataRaw);

            //信息上报
            await _mediator.Publish(new GetKnowledgeInfoSendNotification(data));
        }

        /// <summary>
        /// 知识库变更
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineKnowledgeUpdate)]
        public async Task GetKnowledgeInfoUpdate(KnowledgeSendDto dto)
        {
            var data = _mapper.Map<GetKnowledgeInfoUpdate>(dto);
            data.AreaCode = AreaCode;
            if (data.DisableDate == null)//如果没得有失效时间，默认在生效日期上面加10年
                data.DisableDate = data.BeginDate.Value.AddYears(10);
            //将上报信息写入本地库
            data.Id = await _getKnowledgeInfoUpdateRepository.AddAsync(data);

            //查询原有数据，如果有修改原始数据，没有直接新增
            var dataRaw = await _knowledgeRawDataRepository.GetAsync(p => p.UID == data.UID);
            var raw = _mapper.Map<KnowledgeRawData>(data);
            if (dataRaw != null)
            {
                raw.Id = dataRaw.Id;
                await _knowledgeRawDataRepository.UpdateAsync(raw);
            }
            else
                await _knowledgeRawDataRepository.AddAsync(raw);

            //信息上报
            await _mediator.Publish(new GetKnowledgeInfoUpdateNotification(data));
        }

        /// <summary>
        /// 知识库下架
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        [CapSubscribe(Hotline.Share.Mq.EventNames.HotlineKnowledgeRemove)]
        public async Task GetKnowledgeInfoAbandon(KnowledgeSendDto dto)
        {
            var data = _mapper.Map<GetKnowledgeInfoAbandon>(dto);
            data.AreaCode = AreaCode;
            //将上报信息写入本地库
            data.Id = await _getKnowledgeInfoAbandonRepository.AddAsync(data);

            //知识下架删除原有原始数据
            await _knowledgeRawDataRepository.RemoveAsync(p => p.UID == data.UID, false);

            //信息上报
            await _mediator.Publish(new GetKnowledgeInfoAbandonNotification(data));
        }
        #endregion

        /// <summary>
        /// 实时服务上报
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [NonAction]
        //[CapSubscribe(Hotline.Share.Mq.EventNames.HotlineSendRealTimeStatus)]
        public async Task SendRealTimeStatus(SendRealTimeStatusInfo dto)
        {
            var data = _mapper.Map<SendRealTimeStatus>(dto);
            data.AreaCode = AreaCode;
            //将上报信息写入本地库
            data.Id = await _sendRealTimeStatusRepository.AddAsync(data);

            //信息上报
            await _mediator.Publish(new SendRealTimeStatusNotification(data));
        }
        #endregion
    }
}
