﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications.HuiJu;
using Sharing.Province.Dtos;
using Sharing.Province.Dtos.HuiJu.Send;
using Sharing.Province.HuiJu.Send;
using Sharing.Province.Other;
using Sharing.Repository.Province.HuiJu;

namespace Sharing.Province.Handlers.HuiJu
{
    /// <summary>
    /// 
    /// </summary>
    public class SubmitCaseResultHandler : INotificationHandler<SubmitCaseResultNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly ISubmitCaseResultRepository _submitCaseResultRepository;
        private readonly IWaitingPushDataRepository _waitingPushDataRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        /// <param name="submitCaseResultRepository"></param>
        /// <param name="waitingPushDataRepository"></param>
        public SubmitCaseResultHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider
            , IMapper mapper, ISubmitCaseResultRepository submitCaseResultRepository, IWaitingPushDataRepository waitingPushDataRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _submitCaseResultRepository = submitCaseResultRepository;
            _waitingPushDataRepository = waitingPushDataRepository;
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(SubmitCaseResultNotification notification, CancellationToken cancellationToken)
        {
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var dataReceive = _mapper.Map<List<CaseResult>>(notification.DataOrder);

            //var data = new SubmitCaseResultData
            //{
            //    CaseResults = new List<CaseResult>
            //    {
            //        dataReceive
            //    }
            //};

            var data = new SubmitCaseResultData
            {
                CaseResults = dataReceive
            };
            var request = new SubmitCaseResultRequest();
            request.SetData(data);

            var response = await pusher.PushSubmitCaseResultAsync(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                List<ErrorInfo> list = new();
                if (response.custom != null && response.custom.errorObjs != null && response.custom.errorObjs.Count > 0)
                {
                    list = response.custom.errorObjs;
                }
                foreach (var item in notification.DataOrder)
                {
                    if (list != null && list.Count > 0)
                    {
                        if (list.Find(p => p.caseserial == item.CaseSerial) != null)
                            item.SyncState = "2";
                        else
                            item.SyncState = "1";
                    }
                    else
                        item.SyncState = "1";

                    await _submitCaseResultRepository.UpdateAsync(item);
                    await _waitingPushDataRepository.RemoveAsync(p => p.SyncID == item.Id);
                }
                //if (response.Code == "1")
                //    notification.DataOrder.SyncState = "1";
                //else
                //    notification.DataOrder.SyncState = "2";

                //notification.DataOrder.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                //await _submitCaseResultRepository.UpdateAsync(notification.DataOrder);
            }
        }
    }
}
